==> rfpye-0.3.5.tar.gz: rfpye-0.3.5/setup.py <==
from pkg_resources import parse_version
from configparser import ConfigParser
import setuptools
from Cython.Build import cythonize
import numpy

# from setuptools.command.build_ext import build_ext

# link_args = ['-static-libgcc',
#              '-static-libstdc++',
#              '-Wl,-Bstatic,--whole-archive',
#              '-lwinpthread',
#              '-Wl,--no-whole-archive']

# class Build(build_ext):
#     def build_extensions(self):
#         if self.compiler.compiler_type == 'mingw32':
#             for e in self.extensions:
#                 e.extra_link_args = link_args
#         super(Build, self).build_extensions()

assert parse_version(setuptools.__version__) >= parse_version("36.2")


class get_numpy_include(object):
    """Defer numpy.get_include() until after numpy is installed."""

    def __str__(self):
        import numpy

        return numpy.get_include()


# note: all settings are in settings.ini; edit there, not here
config = ConfigParser(delimiters=["="])
config.read("settings.ini")
cfg = config["DEFAULT"]

cfg_keys = "version description keywords author author_email".split()
expected = (
    cfg_keys
    + "lib_name user branch license status min_python audience language".split()
)
for o in expected:
    assert o in cfg, "missing expected setting: {}".format(o)
setup_cfg = {o: cfg[o] for o in cfg_keys}

licenses = {
    "apache2": (
        "Apache Software License 2.0",
        "OSI Approved :: Apache Software License",
    ),
}
statuses = [
    "1 - Planning",
    "2 - Pre-Alpha",
    "3 - Alpha",
    "4 - Beta",
    "5 - Production/Stable",
    "6 - Mature",
    "7 - Inactive",
]
py_versions = (
    "2.0 2.1 2.2 2.3 2.4 2.5 2.6 2.7 3.0 3.1 3.2 3.3 3.4 3.5 3.6 3.7 3.8 3.9".split()
)

requirements = cfg.get("requirements", "").split()
dev_requirements = (cfg.get("dev_requirements") or "").split()
lic = licenses[cfg["license"]]
min_python = cfg["min_python"]

setuptools.setup(
    name=cfg["lib_name"],
    # cmdclass={'build_ext': Build},
    ext_modules=cythonize("rfpye/cyparser.pyx"),
    include_dirs=[numpy.get_include()],
    license=lic[0],
    classifiers=[
        "Development Status :: " + statuses[int(cfg["status"])],
        "Intended Audience :: " + cfg["audience"].title(),
        "License :: " + lic[1],
        "Natural Language :: " + cfg["language"].title(),
    ]
    + [
        "Programming Language :: Python :: " + o
        for o in py_versions[py_versions.index(min_python) :]
    ],
    url=cfg["git_url"],
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=requirements,
    extras_require={"dev": dev_requirements},
    dependency_links=cfg.get("dep_links", "").split(),
    python_requires=">=" + cfg["min_python"],
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    zip_safe=False,
    entry_points={"console_scripts": cfg.get("console_scripts", "").split()},
    **setup_cfg
)

==> rfpye-0.3.7.tar.gz: rfpye-0.3.7/setup.py <==
from pkg_resources import parse_version
from configparser import ConfigParser
import setuptools
from Cython.Build import cythonize
import numpy

# from setuptools.command.build_ext import build_ext

# link_args = ['-static-libgcc',
#              '-static-libstdc++',
#              '-Wl,-Bstatic,--whole-archive',
#              '-lwinpthread',
#              '-Wl,--no-whole-archive']

# class Build(build_ext):
#     def build_extensions(self):
#         if self.compiler.compiler_type == 'mingw32':
#             for e in self.extensions:
#                 e.extra_link_args = link_args
#         super(Build, self).build_extensions()

assert parse_version(setuptools.__version__) >= parse_version("36.2")


class get_numpy_include(object):
    """Defer numpy.get_include() until after numpy is installed."""

    def __str__(self):
        import numpy
        return numpy.get_include()


# note: all settings are in settings.ini; edit there, not here
config = ConfigParser(delimiters=["="])
config.read("settings.ini")
cfg = config["DEFAULT"]

cfg_keys = "version description keywords author author_email".split()
expected = (
    cfg_keys
    + "lib_name user branch license status min_python audience language".split()
)
for o in expected:
    assert o in cfg, f"missing expected setting: {o}"
setup_cfg = {o: cfg[o] for o in cfg_keys}

licenses = {
    "apache2": (
        "Apache Software License 2.0",
        "OSI Approved :: Apache Software License",
    ),
}
statuses = [
    "1 - Planning",
    "2 - Pre-Alpha",
    "3 - Alpha",
    "4 - Beta",
    "5 - Production/Stable",
    "6 - Mature",
    "7 - Inactive",
]
py_versions = (
    "2.0 2.1 2.2 2.3 2.4 2.5 2.6 2.7 3.0 3.1 3.2 3.3 3.4 3.5 3.6 3.7 3.8 3.9".split()
)

requirements = cfg.get("requirements", "").split()
dev_requirements = (cfg.get("dev_requirements") or "").split()
lic = licenses[cfg["license"]]
min_python = cfg["min_python"]

setuptools.setup(
    name=cfg["lib_name"],
    ext_modules=cythonize("rfpye/cyparser.pyx"),
    include_dirs=[numpy.get_include()],
    license=lic[0],
    classifiers=(
        [
            "Development Status :: " + statuses[int(cfg["status"])],
            "Intended Audience :: " + cfg["audience"].title(),
            f"License :: {lic[1]}",
            "Natural Language :: " + cfg["language"].title(),
        ]
        + [
            f"Programming Language :: Python :: {o}"
            for o in py_versions[py_versions.index(min_python) :]
        ]
    ),
    url=cfg["git_url"],
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=requirements,
    extras_require={"dev": dev_requirements},
    dependency_links=cfg.get("dep_links", "").split(),
    python_requires=">=" + min_python,
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    zip_safe=False,
    entry_points={"console_scripts": cfg.get("console_scripts", "").split()},
    **setup_cfg,
)
